]> git.proxmox.com Git - mirror_frr.git/commitdiff
2004-11-26 Andrew J. Schorr <ajschorr@alumni.princeton.edu>
authorajs <ajs>
Fri, 26 Nov 2004 20:52:59 +0000 (20:52 +0000)
committerajs <ajs>
Fri, 26 Nov 2004 20:52:59 +0000 (20:52 +0000)
* log.c, log.h, memory.c: Change function name from zlog_backtrace_safe
  to the more self-explanatory zlog_backtrace_sigsafe.

lib/ChangeLog
lib/log.c
lib/log.h
lib/memory.c

index f2969e94dccf10fee034f06d0b19719411f45f57..db1f560fab98439c4188b311c8c46ce92f4f9f16 100644 (file)
@@ -1,3 +1,8 @@
+2004-11-26 Andrew J. Schorr <ajschorr@alumni.princeton.edu>
+
+       * log.c, log.h, memory.c: Change function name from zlog_backtrace_safe
+         to the more self-explanatory zlog_backtrace_sigsafe.
+
 2004-11-26 Andrew J. Schorr <ajschorr@alumni.princeton.edu>
 
        * debug.[ch]: Remove unused files.
index 6623b5c91a6f846e31a7d96a93799d5b613a7d9e..86e383391e7fb98aa564c13d2639b75b52606b84 100644 (file)
--- a/lib/log.c
+++ b/lib/log.c
@@ -226,14 +226,14 @@ zlog_signal(int signo, const char *action)
     }
 #undef DUMP
 
-  zlog_backtrace_safe(LOG_ERR);
+  zlog_backtrace_sigsafe(LOG_ERR);
 #undef LOC
 }
 
 /* Log a backtrace using only async-signal-safe functions.
    Needs to be enhanced to support syslog logging. */
 void
-zlog_backtrace_safe(int priority)
+zlog_backtrace_sigsafe(int priority)
 {
 #ifdef HAVE_GLIBC_BACKTRACE
   void *array[20];
index 0df75e733733602cb7d53a895695b87ee9508ee5..17b24cd7a0eb1542ca5ceb1872db01bff77b27cb 100644 (file)
--- a/lib/log.h
+++ b/lib/log.h
@@ -132,6 +132,6 @@ extern void zlog_backtrace(int priority);
    called unless the program is about to exit or abort, since it messes
    up the state of zlog file pointers.  This function needs to be enhanced
    to support syslog logging. */
-extern void zlog_backtrace_safe(int priority);
+extern void zlog_backtrace_sigsafe(int priority);
 
 #endif /* _ZEBRA_LOG_H */
index 0d23e542d5127fc8d6a461b568a2dd49ae1a7a71..8e2c4faa2b35783d74e5194238b84cb23405eef0 100644 (file)
@@ -46,9 +46,9 @@ zerror (const char *fname, int type, size_t size)
   zlog_err ("%s : can't allocate memory for `%s' size %d: %s\n", 
            fname, lookup (mstr, type), (int) size, safe_strerror(errno));
   log_memstats(LOG_WARNING);
/* N.B. It might be preferable to call zlog_backtrace_safe here, since
      that function should definitely be safe in an OOM condition.  But
-     unfortunately zlog_backtrace_safe does not support syslog logging at
+     unfortunately zlog_backtrace_sigsafe does not support syslog logging at
      this time... */
   zlog_backtrace(LOG_WARNING);
   abort();
@@ -46,9 +46,9 @@ zerror (const char *fname, int type, size_t size)
            fname, lookup (mstr, type), (int) size, safe_strerror(errno));
   log_memstats(LOG_WARNING);
-  /* N.B. It might be preferable to call zlog_backtrace_safe here, since
+  /* N.B. It might be preferable to call zlog_backtrace_sigsafe here, since
      that function should definitely be safe in an OOM condition.  But